@@ -117,6 +117,13 @@ class TestPyami(AmiAnyTest):
         pyami.run_command(args)
         assert pyami.flag_dict.get("foo") == 42, f" foo shoule be 42"
 
+    def test_show_version(self):
+        """ensure version is shown
+        """
+        pyami = PyAMI()
+        args = "--version"
+        pyami.run_command(args)
+
 
     @unittest.skip("obsolete")
     def test_multiple_flags(self):
@@ -209,6 +216,8 @@ class TestPyami(AmiAnyTest):
         parser.print_help()
         """usage: [-h] [--verbose] {extra-action,create,update} ...
 
+    
+    
 positional arguments:
   {extra-action,create,update}
                         Desired action to perform
@@ -228,3 +237,22 @@ optional arguments:
   -h, --help  show this help message and exit
   -p P        add db parameter
   """
+
+    def test_version(self):
+        """
+        tests whether version can be extracted fron setup.py
+        """
+        import pkg_resources  # part of setuptools
+
+        # pyami = pkg_resources.require("py4ami")
+        # print(f"pyami {pyami}")
+        # pyami0 = pyami[0]
+        # print(f"pyami0 {pyami0}")
+        # versionx = pyami0.version
+        # return versionx
+
+        pyami = PyAMI()
+        versionx = pyami.version()
+        assert versionx
+
+
